pub enum DvDrMode {
Dv,
Dr,
}Expand description
DV/DR mode selection.
DV mode provides manual repeater configuration; DR mode simplifies operation with automatic repeater selection from the repeater list.
Per Operating Tips 4.2: DR (Digital Repeater) mode combines repeater selection and destination selection. The radio configures RPT1, RPT2, and UR callsign fields automatically based on the user’s choices from the repeater list and destination list.
Variants
Dv
DV (Digital Voice) mode – manual repeater configuration.
Dr
DR (D-STAR Repeater) mode – automatic repeater selection.